@@ -13,9 +13,8 @@ typedef Eo Efl_Io_Closer_Fd;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Close fd using close(2).
- *
- * @since 1.19
  *
  * @ingroup Efl_Io_Closer_Fd
  */
@@ -30,8 +29,6 @@ EWAPI const Efl_Class *efl_io_closer_fd_mixin_get(void);
  * @param[in] obj The object.
  * @param[in] fd File descriptor
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Closer_Fd
  */
 EOAPI void efl_io_closer_fd_set(Eo *obj, int fd);
@@ -44,10 +41,9 @@ EOAPI void efl_io_closer_fd_set(Eo *obj, int fd);
  *
  * @return File descriptor
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Closer_Fd
  */
 EOAPI int efl_io_closer_fd_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
