@@ -25,17 +25,4 @@ typedef Eo Efl_Ui_Layout_Part_Box;
 
 EWAPI const Efl_Class *efl_ui_layout_part_box_class_get(void);
 
-#ifdef EFL_UI_LAYOUT_PART_BOX_PROTECTED
-/**
- * @brief Real part property
- *
- * @param[in] obj The object.
- * @param[in] layout Real part object
- * @param[in] part Real part name
- *
- * @ingroup Efl_Ui_Layout_Part_Box
- */
-EOAPI void efl_ui_layout_part_box_real_part_set(Eo *obj, Efl_Object *layout, const char *part);
-#endif
-
 #endif
